from setuptools import setup

setup(
    name='zxl',
    version='v1.0',
    description='for love',
    py_modules=['zxl'],
    author='upuuuuuu',
    author_email='2226548059@qq.com',
    url='https://github.com/upuuuuuu',
    license='MIT'
)